@@ -6,12 +6,8 @@ class AlreadyInitializedException(OrmException):
     pass
 
 
-class WTFException(OrmException):
-    pass
-
-
 class NotFetchedException(OrmException):
     pass
 
 
-__all__ = ['OrmException', 'AlreadyInitializedException', 'WTFException', 'NotFetchedException']
+__all__ = ['OrmException', 'AlreadyInitializedException', 'NotFetchedException']
